package org.jtheque.books.persistence.dao.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.AuthorImpl;
import org.jtheque.core.managers.persistence.able.JThequeDao;

import java.util.List;

/**
 * A DAO for authors specification.
 *
 * @author Baptiste Wicht
 */
public interface IDaoAuthors extends JThequeDao {
    String TABLE = "T_BOOK_AUTHORS";

    /**
     * Return all the Authors.
     *
     * @return A List containing all the authors.
     */
    List<AuthorImpl> getAuthors();

    /**
     * Return the author with the specified ID.
     *
     * @param id The ID of the searched author.
     * @return The author.
     */
    AuthorImpl getAuthor(int id);

    /**
     * Return the author with the specified ID.
     *
     * @param firstName The searched firstname.
     * @param name      The searched name.
     * @return The author.
     */
    AuthorImpl getAuthor(String firstName, String name);

    /**
     * Indicate if an author with this firstName and this name exists in the application.
     *
     * @param firstName The searched firstname.
     * @param name      The searched name.
     * @return true if an author exist with firstname and this name.
     */
    boolean exists(String firstName, String name);

    /**
     * Save the author.
     *
     * @param author The author to save.
     */
    void save(AuthorImpl author);

    /**
     * Create the author.
     *
     * @param author The author to create.
     */
    void create(AuthorImpl author);

    /**
     * Delete the author.
     *
     * @param author The author to delete.
     * @return true if the object is deleted else false.
     */
    boolean delete(AuthorImpl author);
}