package org.jtheque.books.services.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.AuthorImpl;
import org.jtheque.core.managers.persistence.able.DataContainer;

import java.util.List;

/**
 * A service for the actor functions.
 *
 * @author Baptiste Wicht
 */
public interface IAuthorsService extends DataContainer<AuthorImpl> {
    String DATA_TYPE = "Authors";

    /**
     * Return an empty actor.
     *
     * @return An empty actor.
     */
    AuthorImpl getEmptyAuthor();

    /**
     * Create the author.
     *
     * @param author The author to create.
     */
    void create(AuthorImpl author);

    /**
     * Indicate if an author with this firstname and name exists.
     *
     * @param firstname The firstname to search for.
     * @param name      The name to search for.
     * @return true if the author exist else false.
     */
    boolean exists(String firstname, String name);

    /**
     * Return the author denoted by this firstname and name.
     *
     * @param firstname The firstname to search for.
     * @param name      The name to search for.
     * @return The author.
     */
    AuthorImpl getAuthor(String firstname, String name);

    /**
     * Return all the authors.
     *
     * @return A List containing all the authors.
     */
    List<AuthorImpl> getAuthors();

    /**
     * Delete the author.
     *
     * @param author The author to delete.
     * @return true if the author has been deleted else false.
     */
    boolean delete(AuthorImpl author);

    /**
     * Save the author.
     *
     * @param author The author to save.
     */
    void save(AuthorImpl author);
}