package org.jtheque.books.services.able;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.EditorImpl;
import org.jtheque.core.managers.persistence.able.DataContainer;

import java.util.List;

/**
 * A editors service specification.
 *
 * @author Baptiste Wicht
 */
public interface IEditorsService extends DataContainer<EditorImpl> {
    String DATA_TYPE = "Editors";

    /**
     * Return the default editor.
     *
     * @return The default editor.
     */
    EditorImpl getDefaultEditor();

    /**
     * Create the editor.
     *
     * @param editor The editor to create.
     */
    void create(EditorImpl editor);

    /**
     * Return the editor with the name.
     *
     * @param name The name to search for.
     * @return The editor.
     */
    EditorImpl getEditor(String name);

    /**
     * Indicate if exists an editor with a name.
     *
     * @param name The name to search for.
     * @return true if the author exists else false.
     */
    boolean exists(String name);

    /**
     * Delete the editor.
     *
     * @param editor The editor to delete.
     * @return true if the editor has been deleted else false.
     */
    boolean delete(EditorImpl editor);

    /**
     * Return all the editors.
     *
     * @return A List containing all the editors.
     */
    List<EditorImpl> getEditors();

    /**
     * Save the editor.
     *
     * @param editor The editor to save.
     */
    void save(EditorImpl editor);

    EditorImpl getEmptyEditor();
}