package org.jtheque.books.services.impl;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.dao.able.IDaoBooks;
import org.jtheque.books.persistence.od.BookImpl;
import org.jtheque.books.services.able.IBooksService;
import org.jtheque.books.services.able.IEditorsService;
import org.jtheque.primary.services.able.IKindsService;
import org.jtheque.books.services.able.INotesService;
import org.jtheque.primary.services.able.ITypesService;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.persistence.able.DataListener;
import org.jtheque.primary.services.able.ILanguagesService;

import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.List;

/**
 * A books service implementation.
 *
 * @author Baptiste Wicht
 */
public final class BooksService implements IBooksService {
    private BookImpl defaultBook;

    @Resource
    private ILanguagesService languagesService;

    @Resource
    private INotesService notesService;

    @Resource
    private ITypesService typesService;

    @Resource
    private IEditorsService editorsService;

    @Resource
    private IKindsService kindsService;

    @Resource
    private IDaoBooks daoBooks;

    @Override
    public BookImpl getEmptyBook() {
        if (defaultBook == null) {
            defaultBook = new BookImpl();

            defaultBook.setTitle(Managers.getManager(ILanguageManager.class).getMessage("book.actions.new"));
            defaultBook.setNote(notesService.getDefaultNote());
            defaultBook.setTheEditor(editorsService.getDefaultEditor());
            defaultBook.setTheKind(kindsService.getDefaultKind());
            defaultBook.setTheType(typesService.getDefaultType());
            defaultBook.setTheLanguage(languagesService.getDefaultLanguage());
        }

        return defaultBook;
    }

    @Override
    @Transactional
    public void create(BookImpl book) {
        daoBooks.create(book);
    }

    @Override
    public Collection<? extends BookImpl> getBooks() {
        return daoBooks.getBooks();
    }

    @Override
    @Transactional
    public boolean delete(BookImpl book) {
        return daoBooks.delete(book);
    }

    @Override
    @Transactional
    public void save(BookImpl book) {
        daoBooks.save(book);
    }

    @Override
    public List<BookImpl> getDatas() {
        return daoBooks.getBooks();
    }

    @Override
    public void addDataListener(DataListener listener) {
        daoBooks.addDataListener(listener);
    }

    @Override
    @Transactional
    public void clearAll() {
        daoBooks.clearAll();
    }

    @Override
    public String getDataType() {
        return DATA_TYPE;
    }
}