package org.jtheque.books.services.impl.utils.web;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.BookImpl;
import org.jtheque.books.services.able.INotesService;
import org.jtheque.primary.services.able.ITypesService;
import org.jtheque.books.services.impl.utils.EditArguments;
import org.jtheque.books.services.impl.utils.web.analyzers.AbstractBookAnalyzer;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.core.managers.log.IJThequeLogger;
import org.jtheque.core.managers.log.Logger;
import org.jtheque.primary.services.able.ILanguagesService;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * An amazon getter.
 *
 * @author Baptiste Wicht.
 */
public abstract class AmazonGetter extends AbstractWebGetter {
    @Resource
    private INotesService notesService;

    @Resource
    private ILanguagesService languagesService;

    @Resource
    private ITypesService typesService;

    @Logger
    private IJThequeLogger logger;

    /**
     * Construct a new AmazonGetter.
     */
    AmazonGetter() {
        super();

        Managers.getManager(IBeansManager.class).inject(this);
    }

    @Override
    public List<BookResult> getBooks(final String search) {
        List<BookResult> books = new ArrayList<BookResult>(20);

        Scanner scanner = null;
        try {
            String searched = search.replaceAll(" ", "+");

            URL fileUrl = new URL(getSearchURL() + searched);

            URLConnection urlConnection = fileUrl.openConnection();
            urlConnection.setUseCaches(false);
            urlConnection.connect();

            scanner = new Scanner(urlConnection.getInputStream());

            boolean end = false;

            while (scanner.hasNextLine() && !end) {
                String line = scanner.nextLine();

                if (line.contains("<span class=\"srTitle\">")) {
                    int start = line.indexOf("\">", 26);

                    String index = line.substring(line.indexOf("<a href=\"") + 9, start);
                    String name = line.substring(line.indexOf("<span class=\"srTitle\">") + 22, line.indexOf("</span></a>"));

                    BookResult result = new BookResult();
                    result.setIndex(index);
                    result.setTitle(name);
                    result.setLanguage(getLanguage());

                    books.add(result);
                }

                if (line.contains("Recherche effectue par")) {
                    end = true;
                }
            }
        } catch (MalformedURLException e) {
            logger.exception(e);
        } catch (IOException e) {
            logger.exception(e);
        } finally {
            if (scanner != null) {
                scanner.close();
            }
        }

        return books;
    }

    @Override
    public BookImpl getBook(BookResult search, BookImpl bookToModify, EditArguments args) {
        BookImpl book;

        if (bookToModify == null) {
            book = new BookImpl();
        } else {
            book = bookToModify;

            if (args != null) {
                getAnalyzer().configureWithEditArgs(args);
            }
        }

        getAnalyzer().setBook(book);

        String url = search.getIndex();
        String title = search.getTitle();

        book.setTitle(title);
        book.setTheLanguage(languagesService.getDefaultLanguage());
        book.setNote(notesService.getDefaultNote());
        book.setTheType(typesService.getDefaultType());
        book.setResume("");

        Scanner scanner = null;
        try {
            URL fileUrl = new URL(url);

            URLConnection urlConnection = fileUrl.openConnection();
            urlConnection.setUseCaches(false);
            urlConnection.connect();

            scanner = new Scanner(urlConnection.getInputStream());

            getAnalyzer().setScanner(scanner);

            while (scanner.hasNextLine() && !getAnalyzer().isComplete()) {
                String line = scanner.nextLine().trim();

                getAnalyzer().analyzeLine(line);
            }
        } catch (MalformedURLException e) {
            logger.exception(e);
        } catch (IOException e) {
            logger.exception(e);
        } finally {
            if (scanner != null) {
                scanner.close();
            }
        }

        getAnalyzer().reset();

        return book;
    }

    @Override
    public final AbstractBookAnalyzer getAnalyzer() {
        return (AbstractBookAnalyzer) super.getAnalyzer();
    }

    @Override
    public boolean canGetOn(String language) {
        return getLanguage().equals(language);
    }

    /**
     * Return the managed language.
     *
     * @return The manager language.
     */
    protected abstract String getLanguage();

    /**
     * Return the search URL.
     *
     * @return The search URL.
     */
    protected abstract String getSearchURL();
}