package org.jtheque.books.view.controllers;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.AuthorImpl;
import org.jtheque.books.view.able.IAuthorView;
import org.jtheque.books.view.controllers.able.IAuthorController;
import org.jtheque.books.view.controllers.state.author.AutoAddAuthorState;
import org.jtheque.books.view.controllers.state.author.ModifyAuthorState;
import org.jtheque.books.view.controllers.state.author.NewAuthorState;
import org.jtheque.books.view.controllers.state.author.ViewAuthorState;
import org.jtheque.books.view.models.AuthorsModel;
import org.jtheque.books.services.able.IAuthorsService;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.impl.PrincipalController;
import org.jtheque.primary.view.impl.models.tree.Element;
import org.jtheque.primary.od.abstraction.Data;

import javax.annotation.Resource;
import javax.annotation.PostConstruct;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.tree.TreePath;

import java.util.List;

/**
 * A controller for the author view.
 *
 * @author Baptiste Wicht
 */
public final class AuthorController extends PrincipalController implements IAuthorController {
    @Resource
    private IAuthorView authorView;
    
    @PostConstruct
    public void init() {
        setState(getViewState());
    }

    @Override
    public void valueChanged(TreeSelectionEvent event) {
        TreePath current = ((JTree) event.getSource()).getSelectionPath();

        if (current != null && current.getLastPathComponent() instanceof Element) {
            AuthorImpl author = (AuthorImpl) current.getLastPathComponent();

            if (author != null) {
                ControllerState newState = getState().view(author);

                if (newState != null) {
                    setAndApplyState(newState);
                }
            }
        }
    }

    @Override
    public void save() {
        IAuthorView view = getView();

        ControllerState newState = getState().save(view.fillFilmFormBean());

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public AuthorsModel getViewModel() {
        return (AuthorsModel) getView().getModel();
    }

    @Override
    public void manualEdit() {
        ControllerState newState = getState().manualEdit();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void createAuthor() {
        ControllerState newState = getState().create();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void deleteCurrentAuthor() {
        ControllerState newState = getState().delete();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public void cancel() {
        ControllerState newState = getState().cancel();

        if (newState != null) {
            setAndApplyState(newState);
        }
    }

    @Override
    public IAuthorView getView() {
        return (IAuthorView) authorView;
    }

    @Override
    public String getDataType() {
        return IAuthorsService.DATA_TYPE;
    }

    @Override
    public List<? extends Data> getDisplayList() {
        return getViewModel().getDisplayList();
    }
}