package org.jtheque.books.view.controllers.choice;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.EditorImpl;
import org.jtheque.primary.od.KindImpl;
import org.jtheque.primary.od.SagaImpl;
import org.jtheque.primary.od.TypeImpl;
import org.jtheque.books.services.able.IEditorsService;
import org.jtheque.primary.services.able.IKindsService;
import org.jtheque.primary.services.able.ISagasService;
import org.jtheque.primary.controller.able.ISagaController;
import org.jtheque.books.view.controllers.able.IEditorController;
import org.jtheque.primary.controller.able.IKindController;
import org.jtheque.primary.controller.able.*;
import org.jtheque.primary.od.BorrowerImpl;
import org.jtheque.primary.od.CountryImpl;
import org.jtheque.primary.od.LanguageImpl;
import org.jtheque.primary.services.able.*;
import org.jtheque.primary.view.impl.choice.AbstractChoiceAction;

import javax.annotation.Resource;

/**
 * An action to modify the selected item.
 *
 * @author Baptiste Wicht
 */
public final class ModifyChoiceAction extends AbstractChoiceAction {
    @Resource
    private IKindController kindController;
    
    @Resource
    private ITypeController typeController;
    
    @Resource
    private ILanguageController languageController;
    
    @Resource
    private ICountryController countryController;
    
    @Resource
    private IBorrowerController borrowerController;
    
    @Resource
    private IEditorController editorController;
    
    @Resource
    private ISagaController sagaController;
    
    @Override
    public boolean canDoAction(final String action) {
        return "edit".equals(action);
    }

    @Override
    public void execute() {
        if (IKindsService.DATA_TYPE.equals(getContent())) {
            kindController.editKind((KindImpl) getSelectedItem());
            kindController.displayView();
        } else if (ITypesService.DATA_TYPE.equals(getContent())) {
            typeController.editType((TypeImpl) getSelectedItem());
            typeController.displayView();
        } else if (ILanguagesService.DATA_TYPE.equals(getContent())) {
            languageController.editLanguage((LanguageImpl) getSelectedItem());
            languageController.displayView();
        } else if (ICountriesService.DATA_TYPE.equals(getContent())) {
            countryController.editCountry((CountryImpl) getSelectedItem());
            countryController.displayView();
        } else if (IBorrowersService.DATA_TYPE.equals(getContent())) {
            borrowerController.editBorrower((BorrowerImpl) getSelectedItem());
            borrowerController.displayView();
        } else if (IEditorsService.DATA_TYPE.equals(getContent())) {
            editorController.editEditor((EditorImpl) getSelectedItem());
            editorController.displayView();
        } else if (ISagasService.DATA_TYPE.equals(getContent())) {
            sagaController.editSaga((SagaImpl) getSelectedItem());
            sagaController.displayView();
        }
    }
}