package org.jtheque.books.view.controllers.state.author;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.AuthorImpl;
import org.jtheque.books.services.able.IAuthorsService;
import org.jtheque.books.view.controllers.able.IAuthorController;
import org.jtheque.books.view.controllers.undo.create.CreatedAuthorEdit;
import org.jtheque.books.view.fb.AuthorFormBean;
import org.jtheque.books.view.models.AuthorsModel;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.view.IViewManager;
import org.jtheque.core.managers.undo.IUndoRedoManager;
import org.jtheque.primary.controller.able.ControllerState;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.abstraction.Data;
import org.jtheque.primary.view.able.ViewMode;

import javax.annotation.Resource;

/**
 * The state "new" of the author view.
 *
 * @author Baptiste Wicht
 */
public final class NewAuthorState implements ControllerState {
    @Resource
    private IAuthorController controller;

    @Resource
    private IAuthorsService authorsService;

    @Override
    public AuthorsModel getViewModel() {
        return controller.getViewModel();
    }

    @Override
    public void apply() {
        getViewModel().setCurrentAuthor(authorsService.getEmptyAuthor());
        controller.getView().setEnabled(true);
        controller.getView().getToolbarView().setDisplayMode(ViewMode.NEW);
    }

    @Override
    public ControllerState autoEdit(Data data) {
        switchCurrentAuthor(data);

        return controller.getAutoAddState();
    }

    @Override
    public ControllerState cancel() {
        ControllerState nextState = null;

        controller.getView().selectFirst();

        if (authorsService.getAuthors().size() <= 0) {
            nextState = controller.getViewState();
        }

        return nextState;
    }

    @Override
    public ControllerState create() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState manualEdit() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState delete() {
        //Do nothing

        return null;
    }

    @Override
    public ControllerState save(FormBean bean) {
        AuthorFormBean infos = (AuthorFormBean) bean;

        AuthorImpl author = new AuthorImpl();

        author.setName(infos.getName());
        author.setFirstName(infos.getFirstName());
        author.setNote(infos.getNote());
        author.setTheCountry(infos.getCountry());

        authorsService.create(author);

        Managers.getManager(IUndoRedoManager.class).addEdit(new CreatedAuthorEdit(author));

        controller.getView().resort();

        return controller.getViewState();
    }

    @Override
    public ControllerState view(Data data) {
        switchCurrentAuthor(data);

        return controller.getViewState();
    }

    /**
     * Switch the current author.
     *
     * @param data The author to display.
     */
    private void switchCurrentAuthor(Data data) {
        AuthorImpl author = (AuthorImpl) data;

        if (Managers.getManager(IViewManager.class).askUserForConfirmation(
                Managers.getManager(ILanguageManager.class).getMessage("actor.dialogs.confirmSave"),
                Managers.getManager(ILanguageManager.class).getMessage("actor.dialogs.confirmSave.title"))) {
            controller.save();
        }

        getViewModel().setCurrentAuthor(author);
    }
}