package org.jtheque.books.view.fb;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.AuthorImpl;
import org.jtheque.books.persistence.od.EditorImpl;
import org.jtheque.primary.od.LendingImpl;
import org.jtheque.books.persistence.od.abstraction.Book;
import org.jtheque.core.utils.db.Note;
import org.jtheque.primary.controller.able.FormBean;
import org.jtheque.primary.od.*;
import org.jtheque.utils.collections.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * A form bean for a book.
 *
 * @author Baptiste Wicht
 */
public final class BookFormBean implements FormBean {
    /**
     * The title of the book.
     */
    private String title;

    /**
     * The authors of the book.
     */
    private List<AuthorImpl> authors = new ArrayList<AuthorImpl>(5);

    /**
     * The year of the book.
     */
    private int year;

    /**
     * The number of pages.
     */
    private int pages;

    /**
     * The ISBN-10.
     */
    private String isbn10;

    /**
     * The ISBN-13.
     */
    private String isbn13;

    /**
     * The resume.
     */
    private String resume;

    /**
     * The kind of book.
     */
    private KindImpl theKind;

    /**
     * The type of book.
     */
    private TypeImpl theType;

    /**
     * The note.
     */
    private Note note;

    /**
     * The editor of the book.
     */
    private EditorImpl theEditor;

    /**
     * The language.
     */
    private LanguageImpl theLanguage;

    /**
     * The lending.
     */
    private LendingImpl theLending;

    /**
     * The saga.
     */
    private SagaImpl theSaga;


    /**
     * Return the title of the book.
     *
     * @return The title of the book.
     */
    public String getTitle() {
        return title;
    }

    /**
     * Set the title of the book.
     *
     * @param title The title of the book.
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * Return the authors.
     *
     * @return The authors.
     */
    public List<AuthorImpl> getAuthors() {
        return authors;
    }

    /**
     * Set the authors of the book.
     *
     * @param authors The authors of the book.
     */
    public void setAuthors(List<AuthorImpl> authors) {
        this.authors = CollectionUtils.copyOf(authors);
    }

    /**
     * Return the year.
     *
     * @return The year.
     */
    public int getYear() {
        return year;
    }

    /**
     * Set the year of the book.
     *
     * @param year The year of the book.
     */
    public void setYear(int year) {
        this.year = year;
    }

    /**
     * Return the pages of the book.
     *
     * @return The number of pages of the book.
     */
    public int getPages() {
        return pages;
    }

    /**
     * Set the pages of the book.
     *
     * @param pages The pages of the book.
     */
    public void setPages(int pages) {
        this.pages = pages;
    }

    /**
     * Return the isbn10 of the book.
     *
     * @return The isbn10 of the book.
     */
    public String getIsbn10() {
        return isbn10;
    }

    /**
     * Set the ISBN-10 of the book.
     *
     * @param isbn10 The ISBN-10 of the book.
     */
    public void setIsbn10(String isbn10) {
        this.isbn10 = isbn10;
    }

    /**
     * Return the ISBN-13 of the book.
     *
     * @return The ISBN-13 of the book.
     */
    public String getIsbn13() {
        return isbn13;
    }

    /**
     * Set the ISBN-13 of the book.
     *
     * @param isbn13 The ISBN-13 of the book.
     */
    public void setIsbn13(String isbn13) {
        this.isbn13 = isbn13;
    }

    /**
     * Return the resume of the book.
     *
     * @return The resume of book.
     */
    public String getResume() {
        return resume;
    }

    /**
     * Set the resume of the book.
     *
     * @param resume The resume of the book.
     */
    public void setResume(String resume) {
        this.resume = resume;
    }

    /**
     * Return the kind of the book.
     *
     * @return The kind of the book.
     */
    public KindImpl getTheKind() {
        return theKind;
    }

    /**
     * Set the kind of the book.
     *
     * @param theKind The kind of the book.
     */
    public void setTheKind(KindImpl theKind) {
        this.theKind = theKind;
    }

    /**
     * Return the the type of the book.
     *
     * @return The type of the book.
     */
    public TypeImpl getTheType() {
        return theType;
    }

    /**
     * Set the type of the book.
     *
     * @param theType The type of the book.
     */
    public void setTheType(TypeImpl theType) {
        this.theType = theType;
    }

    /**
     * Return the note of the book.
     *
     * @return The note of the book.
     */
    public Note getNote() {
        return note;
    }

    /**
     * Set the note of the book.
     *
     * @param note The note of the book.
     */
    public void setNote(Note note) {
        this.note = note;
    }

    /**
     * Return the language of the book.
     *
     * @return The language of the book.
     */
    public LanguageImpl getTheLanguage() {
        return theLanguage;
    }

    /**
     * Set the language of the of the book.
     *
     * @param theLanguage The language of the book.
     */
    public void setTheLanguage(LanguageImpl theLanguage) {
        this.theLanguage = theLanguage;
    }

    /**
     * Return the editor of the book.
     *
     * @return The editor of the book.
     */
    public EditorImpl getTheEditor() {
        return theEditor;
    }

    /**
     * Set the editor of the book.
     *
     * @param theEditor The editor of the book.
     */
    public void setTheEditor(EditorImpl theEditor) {
        this.theEditor = theEditor;
    }

    /**
     * Return the lending of the book.
     *
     * @return The lending of the book.
     */
    public LendingImpl getTheLending() {
        return theLending;
    }

    /**
     * Set the lending.
     *
     * @param theLending The lending.
     */
    public void setTheLending(LendingImpl theLending) {
        this.theLending = theLending;
    }

    /**
     * Return the saga of the book.
     *
     * @return The saga of the book.
     */
    public SagaImpl getTheSaga() {
        return theSaga;
    }

    /**
     * Set the saga of the book.
     *
     * @param theSaga The saga of the book.
     */
    public void setTheSaga(SagaImpl theSaga) {
        this.theSaga = theSaga;
    }

    /**
     * Fill the book with the infos of the formbean.
     *
     * @param book The book to fill.
     */
    public void fillBook(Book book) {
        book.setTitle(title);
        book.setTheKind(theKind);
        book.setTheType(theType);
        book.setNote(note);
        book.setAuthors(authors);
        book.setTheEditor(theEditor);
        book.setTheLanguage(theLanguage);
        book.setYear(year);
        book.setPages(pages);
        book.setResume(resume);
    }
}