package org.jtheque.books.view.sort;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.books.persistence.od.abstraction.Book;
import org.jtheque.books.services.able.IBooksService;
import org.jtheque.core.managers.persistence.Entity;
import org.jtheque.core.managers.persistence.able.DataContainerProvider;
import org.jtheque.primary.view.impl.models.tree.Category;
import org.jtheque.primary.view.impl.models.tree.JThequeTreeModel;
import org.jtheque.primary.view.impl.models.tree.RootElement;
import org.jtheque.primary.view.impl.sort.Sorter;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Cette classe permet de raliser un tri par anne.
 *
 * @author Baptiste Wicht
 */
public final class ByYearSorter implements Sorter {
    public static final String SORT_BY_YEAR = "Year";

    @Override
    public boolean canSort(String content, String sortType) {
        return content.equals(IBooksService.DATA_TYPE) && sortType.equals(SORT_BY_YEAR);
    }

    @Override
    public void sort(JThequeTreeModel model) {
        RootElement root = model.getRoot();

        Map<Integer, Category> groups = new HashMap<Integer, Category>(20);
        List<? extends Entity> contents = DataContainerProvider.getInstance().getDatas(IBooksService.DATA_TYPE);

        for (Entity data : contents) {
            Book book = (Book) data;
            int annee = book.getYear();

            if (!groups.containsKey(annee)) {
                Category category = new Category(Integer.toString(annee));

                root.addCategory(category);
                groups.put(annee, category);
            }

            groups.get(annee).addElement(book);
        }

        model.setRootElement(root);
    }
}