package org.jtheque.books.view.toolbar;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.primary.view.able.ToolbarView;
import org.jtheque.primary.view.able.ViewMode;
import org.jtheque.primary.view.impl.components.JDropDownButton;
import org.jtheque.utils.ui.GridBagUtils;

import org.jdesktop.swingx.JXPanel;

import javax.swing.Action;
import javax.swing.JButton;
import javax.annotation.PostConstruct;

import java.util.ArrayList;
import java.util.List;

/**
 * A toolbar for the panel book.
 *
 * @author Baptiste Wicht
 */
public final class JPanelBookToolBar extends JXPanel implements ToolbarView {
    private static final long serialVersionUID = -6509195368792317882L;

    /* Graphics components */
    private JDropDownButton buttonAdd;
    private JDropDownButton buttonEdit;
    private JButton buttonSave;
    private JButton buttonCancel;
    private JButton buttonDelete;

    private Action autoAddAction;
    private Action manualAddAction;
    private Action autoEditAction;
    private Action manualEditAction;
    private Action saveAction;
    private Action cancelAction;
    private Action deleteAction;
    
    private final GridBagUtils gbc = new GridBagUtils();
    
    private ViewMode mode = ViewMode.VIEW;
    
    /**
     * Cette mthode initialise la toolBar.
     */
    @PostConstruct
    private void build() {
        PanelBuilder builder = new PanelBuilder(this);

        buttonSave = new JButton(saveAction);
        buttonCancel = new JButton(cancelAction);
        buttonDelete = new JButton(deleteAction);

        List<Action> adds = new ArrayList<Action>(2);
        adds.add(manualAddAction);
        adds.add(autoAddAction);

        buttonAdd = new JDropDownButton(adds);

        List<Action> edits = new ArrayList<Action>(2);
        edits.add(manualEditAction);
        edits.add(autoEditAction);

        buttonEdit = new JDropDownButton(edits);

        if (mode == ViewMode.VIEW) {
            builder.add(buttonAdd, gbc.gbcSet(0, 0));
            builder.add(buttonEdit, gbc.gbcSet(1, 0));
            builder.add(buttonDelete, gbc.gbcSet(2, 0));
        } else {
            builder.add(buttonSave, gbc.gbcSet(0, 0));
            builder.add(buttonCancel, gbc.gbcSet(1, 0));
        }
    }

    /**
     * Cette mthode permet de modfier le mode.
     *
     * @param mode Le nouveau mode
     */
    void setMode(ViewMode mode) {
        if (this.mode != mode) {
            this.mode = mode;

            remove(buttonSave);
            remove(buttonCancel);
            remove(buttonAdd);
            remove(buttonEdit);
            remove(buttonDelete);

            switch (mode) {
                case VIEW:
                    add(buttonAdd, gbc.gbcSet(0, 0));
                    add(buttonEdit, gbc.gbcSet(1, 0));
                    add(buttonDelete, gbc.gbcSet(2, 0));

                    break;
                case NEW:
                case EDIT:
                case AUTO:
                    add(buttonSave, gbc.gbcSet(0, 0));
                    add(buttonCancel, gbc.gbcSet(1, 0));
                    
                    break;
            }
        }
    }

    @Override
    public void setDisplayMode(ViewMode mode) {
        setMode(mode);
    }

    public void setAutoAddAction(Action autoAddAction) {
        this.autoAddAction = autoAddAction;
    }

    public void setManualAddAction(Action manualAddAction) {
        this.manualAddAction = manualAddAction;
    }

    public void setAutoEditAction(Action autoEditAction) {
        this.autoEditAction = autoEditAction;
    }

    public void setManualEditAction(Action manualEditAction) {
        this.manualEditAction = manualEditAction;
    }

    public void setSaveAction(Action saveAction) {
        this.saveAction = saveAction;
    }

    public void setCancelAction(Action cancelAction) {
        this.cancelAction = cancelAction;
    }

    public void setDeleteAction(Action deleteAction) {
        this.deleteAction = deleteAction;
    }
}